Exception: FulfilApi::Relation::Batchable::RetryLimitExceeded

Inherits:
Error
  • Object
show all
Defined in:
lib/fulfil_api/relation/batchable.rb

Overview

The RetryLimitExceeded is raised when the maximum number of retry requests has been exceeded and we have no other option to cut off the retry mechanism.

Constant Summary

Constants included from Error::Notifiable

Error::Notifiable::EVENT_NAME, Error::Notifiable::REENTRANCY_KEY

Instance Attribute Summary

Attributes inherited from Error

#details

Method Summary

Methods inherited from Error

#initialize, #message

Methods included from Error::Notifiable

#exception, #notify

Constructor Details

This class inherits a constructor from FulfilApi::Error