Exception: FulfilApi::Relation::Batchable::RetryLimitExceeded
- Inherits:
-
Error
- Object
- StandardError
- Error
- FulfilApi::Relation::Batchable::RetryLimitExceeded
- Defined in:
- lib/fulfil_api/relation/batchable.rb
Overview
The RetryLimitExceeded is raised when the maximum number of retry requests has
been exceeded and we have no other option to cut off the retry mechanism.
Constant Summary
Constants included from Error::Notifiable
Error::Notifiable::EVENT_NAME, Error::Notifiable::REENTRANCY_KEY
Instance Attribute Summary
Attributes inherited from Error
Method Summary
Methods inherited from Error
Methods included from Error::Notifiable
Constructor Details
This class inherits a constructor from FulfilApi::Error